@@ -86,7 +86,7 @@ class PacketListModel(QAbstractItemModel):
             self.columns = list(itertools.islice(itertools.chain(
                 (ColumnInfo("hex(payload)", "payload"),),
                 (ColumnInfo("${\"" + x + "\"}", x) for x in self.listObject.buffers[0].metadata.keys()),
-                (ColumnInfo(x) for x in self.listObject.buffers[0].fields.keys())
+                (ColumnInfo("fields[\"" + x + "\"]", x) for x in self.listObject.buffers[0].fields.keys())
             ), 12))
 
     def onNewPacket(self, count):
@@ -239,11 +239,12 @@ class PacketListWidget(QWidget):
             ctx.addSeparator()
         addIdx = None if index == -1 else index
         ctx.addAction("Add Column ...", lambda: self.onAddColumn(addIdx))
+        quick = ctx.addMenu("Quick Add Metadata Column")
         for key in sorted(self.listObject.getAllKeys(metadataKeys=True, fieldKeys=False)):
-            ctx.addAction("$" + key, lambda key=key: self.packetlistmodel.addColumn(ColumnInfo("${\"" + key + "\"}"), addIdx))
-        ctx.addSeparator()
+            quick.addAction("$" + key, lambda key=key: self.packetlistmodel.addColumn(ColumnInfo("${\"" + key + "\"}"), addIdx))
+        quick = ctx.addMenu("Quick Add Field Column")
         for key in sorted(self.listObject.getAllKeys(metadataKeys=False, fieldKeys=True)):
-            ctx.addAction(key, lambda key=key: self.packetlistmodel.addColumn(ColumnInfo("fields[\""+key+"\"]"), addIdx))
+            quick.addAction(key, lambda key=key: self.packetlistmodel.addColumn(ColumnInfo("fields[\""+key+"\"]"), addIdx))
         ctx.addSeparator()
         ctx.addAction("Copy Header State", lambda: setClipboardText("PL-HS:"+b64encode(xdrm.dumps(self.saveState())).decode("ascii")))
         if getClipboardText().startswith("PL-HS:"):
@@ -259,13 +260,13 @@ class PacketListWidget(QWidget):
         ]
 
     def onAddColumn(self, insertBefore):
-        par = showSettingsDlg(self.getColumnInfoDefinition())
+        par = showSettingsDlg(self.getColumnInfoDefinition(), min_width=450)
         if par is not None:
             if par["title"] == "": par["title"] = par["expr_str"]
             self.packetlistmodel.addColumn(ColumnInfo(**par), insertBefore)
 
     def onEditColumn(self, index):
-        par = showSettingsDlg(self.getColumnInfoDefinition(), self.packetlistmodel.columns[index].toDict())
+        par = showSettingsDlg(self.getColumnInfoDefinition(), self.packetlistmodel.columns[index].toDict(), min_width=450)
         if par is not None:
             if par["title"] == "": par["title"] = par["key"]
             self.packetlistmodel.removeColumn(index)
@@ -374,6 +375,9 @@ class ByteBufferWidget(QWidget):
     def run_ndis(self):
         pass
 
+    def clearRanges(self):
+        self.textbox.clearRanges()
+
 
 class DynamicDataWidget(QWidget):
     meta_updated = pyqtSignal(str, object)
@@ -425,3 +429,7 @@ class DynamicDataWidget(QWidget):
         except:
             logging.debug(str(childType)+" has no meta_updated signal")
         self.layout().addWidget(self.childWidget,66)
+
+    def childActionProxy(self):
+        return self.childWidget
+
