@@ -49,6 +49,18 @@ def getMonospaceFont():
 	font.setStyleHint(QFont.Monospace)
 	return font
 
+def getHighlightStyles():
+	#TODO maybe make these user definable
+	return [
+		("R", "Red", {"color": "#aa0000"}),
+		("G", "Green", {"color": "#00aa00"}),
+		("Y", "Yellow", {"color": "#aaaa00"}),
+		("L", "Blue", {"color": "#0000aa"}),
+		("M", "Magenta", {"color": "#aa00aa"}),
+		("T", "Turqoise", {"color": "#00aaaa"}),
+	]
+
+
 def setControlColors(ctrl, bg, fg=None):
 	pal = ctrl.palette()
 	if bg is not None: pal.setColor(ctrl.backgroundRole(), QColor(bg))
@@ -81,11 +93,16 @@ def makeDlgButtonBox(dlg, ok_callback, retval_callback):
 	return btn
 
 
-def showWidgetDlg(widget, title, retval_callback, parent=None, ok_callback=None):
+def showWidgetDlg(widget, title, retval_callback, parent=None, ok_callback=None, min_width=300):
 	dlg = QDialog(parent)
+	dlg.setMinimumWidth(min_width)
 	dlg.setWindowTitle(title)
 	dlg.setLayout(QVBoxLayout())
 	dlg.layout().addWidget(widget)
 	makeDlgButtonBox(dlg, ok_callback, retval_callback)
 	if dlg.exec() == QDialog.Rejected: return None
 	if not ok_callback: return retval_callback()
+
+
+def TODO():
+	QMessageBox.warning(None, "TODO", "Not implemented yet")
