@@ -29,7 +29,7 @@ from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import QMainWindow, QAction, QFileDialog, QWidget, QMessageBox, QToolButton, QLabel, QApplication
 from PyQtAds import ads
 
-from pre_workbench.guihelper import navigateBrowser
+from pre_workbench.guihelper import navigateBrowser, TODO
 from pre_workbench.app import NavigateCommands, GlobalEvents
 from pre_workbench import configs
 # noinspection PyUnresolvedReferences
@@ -57,7 +57,8 @@ class WorkbenchMain(QMainWindow):
 		super().__init__()
 		self.project = project
 		self.mappedChildActions = list()
-		self.curChildMeta = dict()
+		self.activeDocumentMeta = dict()
+		self.activeDocumentWindow = None
 		self._initUI()
 		self.restoreChildren()
 		self.mdiArea.restoreState(self.project.getValue("DockState", b""))
@@ -195,10 +196,10 @@ class WorkbenchMain(QMainWindow):
 				statusTip="Reload the grammar from disk")
 		self.mapChildAction(self.reloadGrammarAct, "reloadGrammar")
 
-		self.openGrammarAct = QAction("&Open grammar", self,
-				shortcut="Ctrl+Shift+I",
-				statusTip="Open a grammar file to parse the current buffer")
-		self.mapChildAction(self.openGrammarAct, "openGrammar")
+		self.clearRangesAct = QAction("&Clear Annotations", self,
+				shortcut="Ctrl+Shift+K",
+				statusTip="Remove all annotations on the current buffer")
+		self.mapChildAction(self.clearRangesAct, "clearRanges")
 
 	def _initMenu(self):
 		menubar = self.menuBar()
@@ -259,10 +260,17 @@ class WorkbenchMain(QMainWindow):
 		self.mapChildAction(a, "zoomReset")
 		viewMenu.addAction(a)
 
+		##### Annotations #####
+		annotationsMenu = menubar.addMenu('&Annotations')
+		annotationsMenu.addAction(self.clearRangesAct)
+		self.loadAnnotationSetMenu = annotationsMenu.addMenu("Load Annotation Set")
+		annotationsMenu.aboutToShow.connect(self._updateParserMenu)
+
 		##### PARSER #####
 		parserMenu = menubar.addMenu('&Parser')
-		parserMenu.addAction(self.openGrammarAct)
 		parserMenu.addAction(self.reloadGrammarAct)
+		self.applyFormatInfoMenu = parserMenu.addMenu("Parse Buffer")
+		parserMenu.aboutToShow.connect(self._updateParserMenu)
 
 		##### TOOLS #####
 		toolsMenu = menubar.addMenu('&Tools')
@@ -275,8 +283,8 @@ class WorkbenchMain(QMainWindow):
 
 		##### WINDOW #####
 		self.windowMenu = menubar.addMenu("&Window")
-		self.updateWindowMenu()
-		self.windowMenu.aboutToShow.connect(self.updateWindowMenu)
+		self._updateWindowMenu()
+		self.windowMenu.aboutToShow.connect(self._updateWindowMenu)
 
 		##### HELP #####
 		helpMenu = menubar.addMenu("&Help")
@@ -312,7 +320,7 @@ class WorkbenchMain(QMainWindow):
 		self.createDockWnd("Data Source Log", "terminal--exclamation.png", LogWidget("DataSource"), ads.TopDockWidgetArea)
 		self.createDockWnd("Application Log", "bug--exclamation.png", LogWidget(""), ads.TopDockWidgetArea)
 
-		self.createDockWnd("Grammar Definition Tree", "tree.png", StructInfoTreeWidget())
+		#self.createDockWnd("Grammar Definition Tree", "tree.png", StructInfoTreeWidget())
 		self.createDockWnd("Grammar Definition Code", "tree--pencil.png", StructInfoCodeWidget(), showFirstRun=True)
 
 		self.createDockWnd("Grammar Parse Result", "tree--arrow.png", RangeTreeDockWidget(), showFirstRun=True)
@@ -400,7 +408,7 @@ class WorkbenchMain(QMainWindow):
 				self.mruActions[i].setText(os.path.basename(mru[i]))
 				self.mruActions[i].setData(mru[i])
 
-	def updateWindowMenu(self):
+	def _updateWindowMenu(self):
 		#TODO
 		return
 		self.windowMenu.clear()
@@ -426,16 +434,38 @@ class WorkbenchMain(QMainWindow):
 			action.triggered.connect(self.windowMapper.map)
 			self.windowMapper.setMapping(action, window)
 
+	def _updateParserMenu(self):
+		self.loadAnnotationSetMenu.clear()
+		self.applyFormatInfoMenu.clear()
+		for name in self.project.getAnnotationSetNames():
+			self.loadAnnotationSetMenu.addAction(name, TODO)
+		self.loadAnnotationSetMenu.addAction("New...", TODO)
+
+		for name in self.project.formatInfoContainer.definitions.keys():
+			self.applyFormatInfoMenu.addAction(name, TODO)
+		#menu.addAction("New...", lambda: )
+
 	def onSubWindowActivated(self, old: ads.CDockWidget, now: ads.CDockWidget):
 		logging.debug("onSubWindowActivated")
 		self.updateMappedChildActions()
 		if now is None or not hasattr(now.widget(), 'child_wnd_meta'): return
+
+		try:
+			self.activeDocumentWindow.widget().meta_updated.disconnect(self.onMetaUpdateChild)
+		except:
+			pass
+		self.activeDocumentWindow = now
+		try:
+			now.widget().meta_updated.connect(self.onMetaUpdateChild)
+		except:
+			pass
+
 		new_meta = now.widget().child_wnd_meta
 		# TODO what about metas only contained in new_meta?
-		for ident, oldval in self.curChildMeta.items():
+		for ident, oldval in self.activeDocumentMeta.items():
 			newval = new_meta.get(ident)
 			if newval != oldval:
-				self.curChildMeta[ident] = newval
+				self.activeDocumentMeta[ident] = newval
 				if hasattr(self, ident+"_updated"): getattr(self, ident+"_updated").emit(newval)
 				self.meta_updated.emit(ident, newval)
 
@@ -492,7 +522,7 @@ class WorkbenchMain(QMainWindow):
 			self.setActiveSubWindow(childWnd)
 
 	@pyqtSlot(str, str)
-	def navigateWindow(self, Type, FileName):
+	def navigateWindow(self, Type, FileName, **kw):
 		childWnd = self.findWindow(Type=Type, FileName=FileName)
 		if childWnd:
 			logging.debug("switching to childWnd: %s", childWnd)
@@ -504,7 +534,7 @@ class WorkbenchMain(QMainWindow):
 			QMessageBox.critical(self, "Failed to open window", "Failed to open window of unknown type "+Type)
 			return
 		try:
-			wnd = winType(fileName=FileName)
+			wnd = winType(fileName=FileName, **kw)
 			self.showChild(wnd)
 		except Exception as ex:
 			msg = QMessageBox(QMessageBox.Critical, "Failed to open file", "Failed to open window of type "+winType.__name__+"\n\n"+str(ex), QMessageBox.Ok, self)
@@ -540,7 +570,7 @@ class WorkbenchMain(QMainWindow):
 
 	def onMetaUpdateChild(self, ident, newval):
 		self.sender().child_wnd_meta[ident] = newval
-		self.curChildMeta[ident] = newval
+		self.activeDocumentMeta[ident] = newval
 		if hasattr(self, ident+"_updated"): getattr(self, ident+"_updated").emit(newval)
 		self.meta_updated.emit(ident, newval)
 
@@ -552,9 +582,6 @@ class WorkbenchMain(QMainWindow):
 		subwnd.setFeature(ads.CDockWidget.DockWidgetForceCloseWithArea, True)
 		subwnd.setWindowIcon(getIcon(type(widget).icon if hasattr(type(widget), 'icon') else 'document.png'))
 		widget.child_wnd_meta = dict()
-		try:
-			widget.meta_updated.connect(self.onMetaUpdateChild)
-		except: pass
 		widget.destroyed.connect(self.updateChildWindowList)
 		if not widget.objectName(): widget.setObjectName(str(uuid.uuid1()))
 		subwnd.setObjectName(widget.objectName())
