@@ -3,7 +3,7 @@ def dec(i):
 	return str(i)
 
 def hex(i):
-	if isinstance(i, bytes):
+	if isinstance(i, (bytes, bytearray)):
 		return ":".join("%02x" % a for a in i)
 	else:
 		return "0x%x" % i
@@ -12,6 +12,6 @@ def dotted_quad(b):
 	return ".".join("%d" % i for i in b)
 
 def ip6(b):
-	return ".".join("%x" % i for i in b)
+	return ":".join("%x" % i for i in b)
 
 
