@@ -87,6 +87,9 @@ class FileBrowserWidget(QWidget):
 			selectedFile = file.absoluteFilePath()
 			selectedFolder = selectedFile if file.isDir() else file.absolutePath()
 			if file.isDir():
+				ctx.addAction("Open as directory of binary files", lambda: navigate("WINDOW", "Type=ObjectWindow", "FileName=" + selectedFile,
+																			   "dataSourceType=DirectoryOfBinFilesDataSource"))
+				ctx.addSeparator()
 				ctx.addAction("Open in file manager", lambda: QDesktopServices.openUrl(QUrl.fromLocalFile(selectedFile)))
 			else:
 				for wndTyp, meta in WindowTypes.types:
@@ -94,6 +97,7 @@ class FileBrowserWidget(QWidget):
 					ctx.addAction(QAction(text, self, statusTip=text, icon=getIcon(meta.get('icon', 'document.png')),
 											   triggered=lambda dummy, meta=meta: navigate("WINDOW", "Type="+meta['name'], "FileName="+selectedFile)))
 				ctx.addSeparator()
+				ctx.addAction("Open in default application", lambda: QDesktopServices.openUrl(QUrl.fromLocalFile(selectedFile)))
 		else:
 			ctx.addAction("Open in file manager", lambda: QDesktopServices.openUrl(QUrl.fromLocalFile(self.model.rootPath())))
 		#ctx.addAction("Set root folder ...", lambda: self.selectRootFolder(preselect=selectedFolder))
@@ -307,11 +311,7 @@ class DataInspectorWidget(QWidget):
 		with PerfTimer("DataInspector parsing"):
 			if not self.selbytes: return
 			parse_context = AnnotatingParseContext(self.fiTreeWidget.formatInfoContainer, self.selbytes) #buffer.getBytes(range.start, range.length()))
-			try:
-				fi_tree = parse_context.parse()
-			except parse_exception as ex:
-				logging.exception("Failed to apply format info")
-				logging.getLogger("DataSource").error("Failed to apply format info: "+str(ex))
+			fi_tree = parse_context.parse()
 			self.fiTreeWidget.updateTree([fi_tree])
 
 	def _initUI(self):
@@ -537,7 +537,9 @@ class SearchDockWidget(QWidget):
 		toolbar.addWidget(self.cmdLineEdit)
 		self.treeView = QTreeWidget()
 		self.treeView.setColumnCount(2)
-		self.treeView.setColumnWidth(1, 300)
+		self.treeView.setColumnWidth(0, 300)
+		self.treeView.headerItem().setText(0, "Result")
+		self.treeView.headerItem().setText(1, "Offset")
 		self.treeView.itemClicked.connect(self._itemClicked)
 		windowLayout = QVBoxLayout()
 		windowLayout.addWidget(toolbar)
@@ -561,10 +563,12 @@ class SearchDockWidget(QWidget):
 		if not self.hexview: return
 		pattern = re.compile(findStr.encode('latin1'))
 		for i,buf in enumerate(self.hexview.buffers):
-			root = QTreeWidgetItem(self.treeView)
-			root.setText(0, "Buffer %d"%i)
-			root.setExpanded(True)
+			root = None
 			for match in pattern.finditer(buf.buffer):
+				if not root:
+					root = QTreeWidgetItem(self.treeView)
+					root.setText(0, "Buffer %d: %r" % (i, buf.metadata))
+					root.setExpanded(True)
 				x = QTreeWidgetItem(root)
 				x.setText(0, match.group(0).decode('latin1'))
 				x.setText(1, str(match.start()))
